@@ -15,12 +15,17 @@
 #
 # History
 # 24.11.2009    version 1
+# 22.12.2009    version 2 (mvdl) added left limit.
 #
 
 getWeibullLimit <- function(y, p, N, rho)
 {
    param <- fitWeibull(y,p)
-   ell <- param$lambda*log(N/rho)^(1/param$k)
+   ell <- c(Left=0, Right=Inf)
+   if ( !is.na(rho[1]) )
+      ell[1] <- param$lambda*(-log(1-rho[1]/N))^(1/param$k)
+   if ( !is.na(rho[2]) )
+      ell[2] <- param$lambda*log(N/rho[2])^(1/param$k)
    return(list(k=param$k, 
                lambda=param$lambda,
                nFit=length(y),
